@@ -1,7 +1,7 @@
 /*
  * This file is part of the trojan project.
  * Trojan is an unidentifiable mechanism that helps you bypass GFW.
- * Copyright (C) 2017-2019  GreaterFire
+ * Copyright (C) 2017-2020  The Trojan Authors.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ public:
     SOCKS5Address address;
     uint16_t length;
     std::string payload;
-    int parse(const std::string &data);
+    bool parse(const std::string &data, size_t &udp_packet_len);
     static std::string generate(const boost::asio::ip::udp::endpoint &endpoint, const std::string &payload);
     static std::string generate(const std::string &domainname, uint16_t port, const std::string &payload);
 };
